Computations
============


Pure parallel computations
--------------------------

.. automodule:: reikna.pureparallel
    :members:


Linear algebra
--------------

.. automodule:: reikna.matrixmul
    :members:

.. automodule:: reikna.transpose
    :members:


Algorithms
----------

.. automodule:: reikna.reduce
    :members:


Fast Fourier transform
----------------------

.. currentmodule:: reikna.fft
.. autoclass :: reikna.fft.FFT


Discrete harmonic transform
---------------------------

.. currentmodule:: reikna.dht
.. autofunction :: reikna.dht.get_spatial_grid
.. autofunction :: reikna.dht.harmonic
.. autoclass :: reikna.dht.DHT


Counter-based random number generators
--------------------------------------

.. automodule:: reikna.cbrng
